==> open-xchange-core_7.6.2.orig.tar.bz2: open-xchange-core-7.6.2/com.openexchange.server/src/com/openexchange/tools/images/transformations/TransformedImageImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.tools.images.transformations;

import com.openexchange.tools.images.TransformedImage;

/**
 * {@link TransformedImageImpl}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class TransformedImageImpl implements TransformedImage {

    private final int width;
    private final int height;
    private final long size;
    private final String formatName;
    private final byte[] imageData;
    private final byte[] md5;
    private final int transformationExpenses;

    public TransformedImageImpl(int width, int height, long size, String formatName, byte[] imageData, byte[] md5, final int transformationExpenses) {
        super();
        this.width = width;
        this.height = height;
        this.size = size;
        this.formatName = formatName;
        this.imageData = imageData;
        this.md5 = md5;
        this.transformationExpenses = transformationExpenses;
    }

    @Override
    public int getWidth() {
        return width;
    }

    @Override
    public int getHeight() {
        return height;
    }

    @Override
    public long getSize() {
        return size;
    }

    @Override
    public String getFormatName() {
        return formatName;
    }

    @Override
    public byte[] getImageData() {
        return imageData;
    }

    @Override
    public byte[] getMD5() {
        return md5;
    }

    @Override
    public int getTransformationExpenses() {
        return transformationExpenses;
    }

    @Override
    public String toString() {
        return formatName + " | " + width + " x " + height + " | " + size + " bytes";
    }

}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.server/src/com/openexchange/tools/images/transformations/TransformedImageImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.tools.images.transformations;

import java.io.InputStream;
import com.openexchange.ajax.container.ThresholdFileHolder;
import com.openexchange.ajax.fileholder.IFileHolder;
import com.openexchange.exception.OXException;
import com.openexchange.imagetransformation.TransformedImage;
import com.openexchange.java.Streams;

/**
 * {@link TransformedImageImpl}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class TransformedImageImpl implements TransformedImage {

    private final int width;
    private final int height;
    private final long size;
    private final String formatName;
    private final byte[] imageData;
    private final ThresholdFileHolder imageFile;
    private final byte[] md5;
    private final int transformationExpenses;

    public TransformedImageImpl(int width, int height, long size, String formatName, byte[] imageData, byte[] md5, final int transformationExpenses) {
        super();
        this.width = width;
        this.height = height;
        this.size = size;
        this.formatName = formatName;
        this.imageData = imageData;
        this.imageFile = null;
        this.md5 = md5;
        this.transformationExpenses = transformationExpenses;
    }

    public TransformedImageImpl(int width, int height, long size, String formatName, ThresholdFileHolder imageFile, byte[] md5, final int transformationExpenses) {
        super();
        if (null == imageFile) {
            throw new IllegalArgumentException("imageFile must not be null");
        }
        this.width = width;
        this.height = height;
        this.size = size;
        this.formatName = formatName;
        this.imageData = null;
        this.imageFile = imageFile;
        this.md5 = md5;
        this.transformationExpenses = transformationExpenses;
    }

    @Override
    public int getWidth() {
        return width;
    }

    @Override
    public int getHeight() {
        return height;
    }

    @Override
    public long getSize() {
        return size;
    }

    @Override
    public String getFormatName() {
        return formatName;
    }

    @Override
    public byte[] getImageData() throws OXException {
        return null != imageData ? imageData : imageFile.toByteArray();
    }

    @Override
    public InputStream getImageStream() throws OXException {
        return null != imageData ? Streams.newByteArrayInputStream(imageData) : imageFile.getStream();
    }

    @Override
    public IFileHolder getImageFile() {
        return imageFile;
    }

    @Override
    public byte[] getMD5() {
        return md5;
    }

    @Override
    public int getTransformationExpenses() {
        return transformationExpenses;
    }

    @Override
    public String toString() {
        return formatName + " | " + width + " x " + height + " | " + size + " bytes";
    }

    @Override
    public void close() {
        ThresholdFileHolder imageFile = this.imageFile;
        if (null != imageFile) {
            imageFile.close();
        }
    }

}
